pub unsafe extern "C" fn tamp_decompressor_init(
decompressor: *mut TampDecompressor,
conf: *const TampConf,
window: *mut c_uchar,
) -> tamp_resExpand description
@brief Initialize decompressor object.
@param[in,out] TampDecompressor object to perform decompression with. @param[in] conf Compressor configuration. Set to NULL to perform an implicit header read. @param[in] window Pre-allocated window buffer. Size must agree with conf->window. If conf.use_custom_dictionary is true, then the window must be externally initialized and be at least as big as conf->window.